All Packages

Package Summary
Package
Description
This artifact provides a Reactor for breaking up dependencies between a Java software system's components or modules, which enables them to be developed and tested independently (dependency injection and inversion of control).