Module org.refcodes.decoupling
module org.refcodes.decoupling
-
Packages
ExportsPackageDescriptionThis artifact provides aReactorfor breaking up dependencies between a Java software system's components or modules, which enables them to be developed and tested independently (dependency injection and inversion of control).