Annotation Interface Alias


@Documented @Retention(RUNTIME) @Target(PARAMETER) public @interface Alias
The Alias annotation denotes a parameter with an additional alias for tackling such a parameter with a Dependency's alias (as of Dependency.getAlias() when resolving dependencies.