Class Claim

java.lang.Object
org.refcodes.decoupling.Claim
All Implemented Interfaces:
Comparable<Claim>, AliasAccessor, TypeAccessor, Diagnosable, Schemable<DiagnosticOptions>
Direct Known Subclasses:
FactoryClaim, InitializerClaim

public class Claim extends Object implements AliasAccessor, TypeAccessor, Diagnosable, Comparable<Claim>
A claim describes a Claim required by a Dependency.
  • Field Details

  • Constructor Details

    • Claim

      protected Claim()
      Instantiates a new Claim.
    • Claim

      public Claim(Class<?> aType)
      Constructs a Claim for the given type (the alias is, if not provided, derived from type).
      Parameters:
      aType - The type of the Claim.
    • Claim

      public Claim(String aAlias)
      Constructs a Claim for the given type (the alias is, if not provided, derived from type).
      Parameters:
      aAlias - The alias for the Claim.
    • Claim

      public Claim(Class<?> aType, String aAlias)
      Constructs a Claim for the given type (the alias is, if not provided, derived from type).
      Parameters:
      aType - The type of the Claim.
      aAlias - The alias for the Claim.
  • Method Details