Interface ClaimAccessor

All Known Subinterfaces:
ClaimAccessor.ClaimProperty
All Known Implementing Classes:
AmbigousClaimException, DependencyException.ClaimDependenciesException, DependencyException.DependencyClaimException, DuplicateClaimException, UnsatisfiedClaimException

public interface ClaimAccessor
Provides an accessor for a Claim instance property.
  • Method Details

    • getClaim

      Claim getClaim()
      Retrieves the Claim instance from the Claim instance property.
      Returns:
      The Claim instance stored by the Claim instance property.