Interface ClaimAccessor.ClaimBuilder<B extends ClaimAccessor.ClaimBuilder<B>>

Type Parameters:
B - The builder to return in order to be able to apply multiple build operations.
Enclosing interface:
ClaimAccessor

public static interface ClaimAccessor.ClaimBuilder<B extends ClaimAccessor.ClaimBuilder<B>>
Provides a builder method for a Claim instance property returning the builder for applying multiple build operations.
  • Method Summary

    Modifier and Type
    Method
    Description
    withClaim(Claim aClaim)
    Sets the Claim instance for the Claim instance property.
  • Method Details

    • withClaim

      B withClaim(Claim aClaim)
      Sets the Claim instance for the Claim instance property.
      Parameters:
      aClaim - The Claim instance to be stored by the Claim instance property.
      Returns:
      The builder for applying multiple build operations.