Interface ClaimAccessor.ClaimMutator

All Known Subinterfaces:
ClaimAccessor.ClaimProperty
Enclosing interface:
ClaimAccessor

public static interface ClaimAccessor.ClaimMutator
Provides a mutator for a Claim instance property.
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    setClaim(Claim aClaim)
    Sets the Claim instance for the Claim instance property.
  • Method Details

    • setClaim

      void setClaim(Claim aClaim)
      Sets the Claim instance for the Claim instance property.
      Parameters:
      aClaim - The Claim instance to be stored by the Claim instance property.