Class Context

java.lang.Object
org.refcodes.decoupling.Context
All Implemented Interfaces:
DependenciesAccessor, Diagnosable, Schemable<DiagnosticOptions>

public class Context extends Object implements DependenciesAccessor, Diagnosable
The Context describes the components and modules wired together by the Reactor.
  • Constructor Details

    • Context

      protected Context(Object[] aProfiles)
      Empty constructor to be used in conjunction with the initialize(Dependency[]) method!.
      Parameters:
      aProfiles - The profiles which have been applied when creating this Context.
    • Context

      public Context(Dependency<?>[] aDependencies, Object[] aProfiles)
      Creates the Context with the managed Dependency instances.
      Parameters:
      aDependencies - The Dependency declarations of which the Context consists.
      aProfiles - The profiles which have been applied when creating this Context.
  • Method Details