Class DependencySchema

java.lang.Object
java.util.AbstractMap<String,Object>
java.util.HashMap<String,Object>
org.refcodes.schema.Schema
org.refcodes.decoupling.DependencySchema
All Implemented Interfaces:
Serializable, Cloneable, Map<String,Object>, org.refcodes.exception.ExceptionAccessor<Throwable>, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.ChildrenAccessor<org.refcodes.schema.Schema[]>, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.HashAccessor, org.refcodes.mixin.IdentifierAccessor, org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.SizeAccessor, org.refcodes.mixin.StereotypeAccessor<String>, org.refcodes.mixin.TypeAccessor, org.refcodes.mixin.ValueAccessor<Object>

public class DependencySchema extends org.refcodes.schema.Schema implements org.refcodes.mixin.SizeAccessor
The purpose of a DependencySchema is to automatically outline and generate documentation of Dependency configuration.
See Also:
  • Nested Class Summary

    Nested Classes
    Modifier and Type
    Class
    Description
    static final class 
    DependencySchema.Builder to build
    invalid reference
    DependnecySchema
    .

    Nested classes/interfaces inherited from class AbstractMap

    AbstractMap.SimpleEntry<K,V>, AbstractMap.SimpleImmutableEntry<K,V>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor

    org.refcodes.mixin.AliasAccessor.AliasBuilder<B>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.ChildrenAccessor

    org.refcodes.mixin.ChildrenAccessor.ChildrenBuilder<T,B>, org.refcodes.mixin.ChildrenAccessor.ChildrenMutator<T>, org.refcodes.mixin.ChildrenAccessor.ChildrenProperty<T>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor

    org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty

    Nested classes/interfaces inherited from interface org.refcodes.exception.ExceptionAccessor

    org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC,B>, org.refcodes.exception.ExceptionAccessor.ExceptionMutator<EXC>, org.refcodes.exception.ExceptionAccessor.ExceptionProperty<EXC>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.HashAccessor

    org.refcodes.mixin.HashAccessor.HashBuilder<B>, org.refcodes.mixin.HashAccessor.HashMutator, org.refcodes.mixin.HashAccessor.HashProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.IdentifierAccessor

    org.refcodes.mixin.IdentifierAccessor.IdentifierBuilder<B>, org.refcodes.mixin.IdentifierAccessor.IdentifierMutator, org.refcodes.mixin.IdentifierAccessor.IdentifierProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor

    org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B>, org.refcodes.mixin.KeyAccessor.KeyMutator<K>, org.refcodes.mixin.KeyAccessor.KeyProperty<K>

    Nested classes/interfaces inherited from interface Map

    Map.Entry<K,V>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.SizeAccessor

    org.refcodes.mixin.SizeAccessor.SizeBuilder<B>, org.refcodes.mixin.SizeAccessor.SizeMutator, org.refcodes.mixin.SizeAccessor.SizeProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.StereotypeAccessor

    org.refcodes.mixin.StereotypeAccessor.StereotypeBuilder<T,B>, org.refcodes.mixin.StereotypeAccessor.StereotypeMutator<T>, org.refcodes.mixin.StereotypeAccessor.StereotypeProperty<T>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor

    org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor

    org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>, org.refcodes.mixin.ValueAccessor.ValueMutator<V>, org.refcodes.mixin.ValueAccessor.ValueProperty<V>
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final String
     
    static final String
     
    static final String
     
    static final String
     
    static final String
     
    static final String
     
    static final String
     
    static final String
     
    static final String
     
    static final String
     
    static final String
     
    static final String
     
    static final String
     
    static final String
     

    Fields inherited from class org.refcodes.schema.Schema

    _children, ALIAS, ASSOCIATION, DESCRIPTION, EXCEPTION, HASH, HASH_SEPARATOR, IDENTIFIER, KEY, STEREOTYPE, TYPE, VALUE
  • Constructor Summary

    Constructors
    Constructor
    Description
    DependencySchema(String aIdentifier, String aAlias, String aKey, Class<?> aType, Integer aHash, Object aValue, String aStereotype, Throwable aException, String aDescription, org.refcodes.schema.Schema aSchema, org.refcodes.schema.Schema[] aChildren)
    Constructs a DependencySchema with the provided arguments.
  • Method Summary

    Modifier and Type
    Method
    Description
    Creates builder to build
    invalid reference
    DependnecySchema
    .
    int

    Methods inherited from class org.refcodes.schema.Schema

    getAlias, getChildren, getDescription, getException, getHash, getIdentifier, getKey, getStereotype, getType, getValue, init, toLabel, toNotation, toObjectId, toSimpleObjectId, toString, visit

    Methods inherited from class AbstractMap

    equals, hashCode

    Methods inherited from class Object

    finalize, getClass, notify, notifyAll, wait, wait, wait

    Methods inherited from interface Map

    equals, hashCode

    Methods inherited from interface org.refcodes.mixin.ValueAccessor

    getValueOr
  • Field Details

  • Constructor Details

    • DependencySchema

      public DependencySchema(String aIdentifier, String aAlias, String aKey, Class<?> aType, Integer aHash, Object aValue, String aStereotype, Throwable aException, String aDescription, org.refcodes.schema.Schema aSchema, org.refcodes.schema.Schema[] aChildren)
      Constructs a DependencySchema with the provided arguments.
      Parameters:
      aIdentifier - The identifier being the label for the Schema, when null the alias, the key or the type's simple name prefixed with the @ character alongside the hash (or this instance's identity has code when null).
      aAlias - The alias (name) describing this Schema, when null, then the alias is extrapolated from the identifier's portion till the last @ character (if any).
      aKey - The key (of a value) provided with this Schema
      aType - The type described by this Schema.
      aHash - The hash if the instance described by this Schema.
      aValue - The value representing this Schema.
      aStereotype - The stereotype related with this Schema.
      aException - The Throwable related with this Schema.
      aDescription - The description for this Schema.
      aSchema - The Schema from which to copy from (in case of not being explicitly set by the arguments).
      aChildren - The Schema's children (aggregation structure).
  • Method Details

    • getSize

      public int getSize()
      Specified by:
      getSize in interface org.refcodes.mixin.SizeAccessor
    • builder

      public static DependencySchema.Builder builder()
      Creates builder to build
      invalid reference
      DependnecySchema
      .
      Returns:
      created builder