Class InstallDependencyException

All Implemented Interfaces:
Serializable, DependencyAccessor, ErrorCodeAccessor, Trap

public class InstallDependencyException extends DependencyException
This exception is thrown when trying to install a Dependency into the Context, though installing failed due to the dependency throwing an exception during the process of installing (e.g. instantiation).
See Also: