Interface InstanceMetrics

All Known Implementing Classes:
InstanceMode

public interface InstanceMetrics
The InstanceMetrics define the creation of a Dependency's instance and it's combinations are provided for convenience means by the enumeration InstanceMode.
  • Method Summary

    Modifier and Type
    Method
    Description
    boolean
    True in case a Dependency is required to be instantiated in any case, even if not being demanded by another dependency.
    boolean
    True in case the Dependency represents a singleton.
  • Method Details

    • isSingleton

      boolean isSingleton()
      True in case the Dependency represents a singleton.
      Returns:
      True in case of being a singleton Dependency.
    • isMandatory

      boolean isMandatory()
      True in case a Dependency is required to be instantiated in any case, even if not being demanded by another dependency.
      Returns:
      True in case of being a required Dependency.