Module org.refcodes.decoupling
Package org.refcodes.decoupling
Interface ProfilesAccessor.ProfilesProperty
- All Superinterfaces:
ProfilesAccessor,ProfilesAccessor.ProfilesMutator
- All Known Implementing Classes:
DependencyBuilder
- Enclosing interface:
- ProfilesAccessor
public static interface ProfilesAccessor.ProfilesProperty
extends ProfilesAccessor, ProfilesAccessor.ProfilesMutator
Provides a profiles property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.decoupling.ProfilesAccessor
ProfilesAccessor.ProfilesBuilder<B extends ProfilesAccessor.ProfilesBuilder<B>>, ProfilesAccessor.ProfilesMutator, ProfilesAccessor.ProfilesProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault Object[]letProfiles(Object[] aProfiles) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenObject(setter) as ofProfilesAccessor.ProfilesMutator.setProfiles(Object[])and returns the very same value (getter).Methods inherited from interface org.refcodes.decoupling.ProfilesAccessor
getProfilesMethods inherited from interface org.refcodes.decoupling.ProfilesAccessor.ProfilesMutator
setProfiles
-
Method Details
-
letProfiles
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenObject(setter) as ofProfilesAccessor.ProfilesMutator.setProfiles(Object[])and returns the very same value (getter).- Parameters:
aProfiles- TheObjectto set (viaProfilesAccessor.ProfilesMutator.setProfiles(Object[])).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-