Class Reactor

java.lang.Object
org.refcodes.decoupling.Reactor

public class Reactor extends Object
A Reactor's instance is used for breaking up dependencies between a Java software system's components or modules, which enables them to be developed and tested independently (dependency injection and inversion of control). The reactor wires components or modules together to form an interacting application. The Reactor uses dependency injection and inversion of control, which are two techniques that help achieve decoupling by allowing components to depend on abstractions instead of concrete implementations.