Uses of Class
org.refcodes.decoupling.AmbigousFactoryException
-
Uses of AmbigousFactoryException in org.refcodes.decoupling
Methods in org.refcodes.decoupling that throw AmbigousFactoryExceptionModifier and TypeMethodDescriptionReactor.createContext()Reactor.createContext(Object... aProfiles) Reactor.createContext(String... aProfiles) protected TDependency.toInstance(Dependency<?>[] aDependencies, Object... aProfiles) Creates theDependency's instance as of its type using the providedDependencydeclarations.protected TDependency.toInstance(Dependency<?>[] aDependencies, Set<Dependency<?>> aVistedDependencies, Object... aProfiles) Creates theDependency's instance as of its type using the providedDependencydeclarations.