Uses of Class
org.refcodes.decoupling.Claim
-
Uses of Claim in org.refcodes.decoupling
Subclasses of Claim in org.refcodes.decouplingModifier and TypeClassDescriptionclassFactoryClaim<C,T> AFactoryClaimextends aClaimand uses aFunctionupon aDependencyto create (fabricate) an instance.classInitializerClaim<C,T> AInitializerClaimextends aClaimand uses aBiFunctionupon aDependencyto initialize a given instance.Classes in org.refcodes.decoupling that implement interfaces with type arguments of type ClaimFields in org.refcodes.decoupling declared as ClaimModifier and TypeFieldDescriptionprotected ClaimDependencyException.ClaimDependenciesException._claimprotected ClaimDependencyException.DependencyClaimException._claimprotected Claim[]DependencyException.DependencyClaimException._claimsFields in org.refcodes.decoupling with type parameters of type ClaimMethods in org.refcodes.decoupling that return ClaimModifier and TypeMethodDescriptionClaimAccessor.getClaim()DependencyException.ClaimDependenciesException.getClaim()Retrieves theClaiminstance responsible for this exception.DependencyException.DependencyClaimException.getClaim()Claim[]ClaimsAccessor.getClaims()Claim[]Dependency.getClaims()Claim[]DependencyException.DependencyClaimException.getClaims()default ClaimThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenClaim(setter) as ofClaimAccessor.ClaimMutator.setClaim(Claim)and returns the very same value (getter).default Claim[]This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenClaim(setter) as ofClaimsAccessor.ClaimsMutator.setClaims(Claim[])and returns the very same value (getter).Methods in org.refcodes.decoupling with parameters of type ClaimModifier and TypeMethodDescriptionbooleanintdefault ClaimThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenClaim(setter) as ofClaimAccessor.ClaimMutator.setClaim(Claim)and returns the very same value (getter).default Claim[]This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenClaim(setter) as ofClaimsAccessor.ClaimsMutator.setClaims(Claim[])and returns the very same value (getter).voidvoidvoidDependencyBuilder.withAddClaim(Claim aClaim) Builder method for the accordingDependencyBuilder.addClaim(Claim)method.ClaimsAccessor.ClaimsBuilder.withClaims(Claim... aClaims) DependencyBuilder.withClaims(Claim... aClaims) Method parameters in org.refcodes.decoupling with type arguments of type ClaimModifier and TypeMethodDescriptionvoidDependencyBuilder.setClaims(Collection<Claim> aClaims) Sets theClaiminstances to theDependencyBuilderinstance.DependencyBuilder.withClaims(Collection<Claim> aClaims) Builder method for theDependencyBuilder.setClaims(Claim[])method.Constructors in org.refcodes.decoupling with parameters of type ClaimModifierConstructorDescriptionAmbigousClaimException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies) Instantiates the classAmbigousClaimException.AmbigousClaimException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, String aErrorCode) Instantiates the classAmbigousClaimException.AmbigousClaimException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) Instantiates the classAmbigousClaimException.AmbigousClaimException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates the classAmbigousClaimException.AmbigousClaimException(Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) Instantiates the classAmbigousClaimException.AmbigousClaimException(Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates the classAmbigousClaimException.ClaimDependenciesException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies) Instantiates the classDependencyException.ClaimDependenciesException.ClaimDependenciesException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, String aErrorCode) Instantiates the classDependencyException.ClaimDependenciesException.ClaimDependenciesException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) Instantiates the classDependencyException.ClaimDependenciesException.ClaimDependenciesException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates the classDependencyException.ClaimDependenciesException.ClaimDependenciesException(Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) Instantiates the classDependencyException.ClaimDependenciesException.ClaimDependenciesException(Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates the classDependencyException.ClaimDependenciesException.DependencyClaimException(String aMessage, Claim aClaim, Claim[] aClaims, Dependency<?> aDependency) Instantiates the classDependencyException.DependencyClaimException.DependencyClaimException(String aMessage, Claim aClaim, Claim[] aClaims, Dependency<?> aDependency, String aErrorCode) Instantiates the classDependencyException.DependencyClaimException.DependencyClaimException(String aMessage, Claim aClaim, Claim[] aClaims, Dependency<?> aDependency, Throwable aCause) Instantiates the classDependencyException.DependencyClaimException.DependencyClaimException(String aMessage, Claim aClaim, Claim[] aClaims, Dependency<?> aDependency, Throwable aCause, String aErrorCode) Instantiates the classDependencyException.DependencyClaimException.DependencyClaimException(Claim aClaim, Claim[] aClaims, Dependency<?> aDependency, Throwable aCause) Instantiates the classDependencyException.DependencyClaimException.DependencyClaimException(Claim aClaim, Claim[] aClaims, Dependency<?> aDependency, Throwable aCause, String aErrorCode) Instantiates the classDependencyException.DependencyClaimException.DuplicateClaimException(String aMessage, Claim aClaim, Claim[] aClaims, Dependency<?> aDependency) Instantiates the classDuplicateClaimException.DuplicateClaimException(String aMessage, Claim aClaim, Claim[] aClaims, Dependency<?> aDependency, String aErrorCode) Instantiates the classDuplicateClaimException.DuplicateClaimException(String aMessage, Claim aClaim, Claim[] aClaims, Dependency<?> aDependency, Throwable aCause) Instantiates the classDuplicateClaimException.DuplicateClaimException(String aMessage, Claim aClaim, Claim[] aClaims, Dependency<?> aDependency, Throwable aCause, String aErrorCode) Instantiates the classDuplicateClaimException.DuplicateClaimException(Claim aClaim, Claim[] aClaims, Dependency<?> aDependency, Throwable aCause) Instantiates the classDuplicateClaimException.DuplicateClaimException(Claim aClaim, Claim[] aClaims, Dependency<?> aDependency, Throwable aCause, String aErrorCode) Instantiates the classDuplicateClaimException.UnsatisfiedClaimException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies) Instantiates the classUnsatisfiedClaimException.UnsatisfiedClaimException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, String aErrorCode) Instantiates the classUnsatisfiedClaimException.UnsatisfiedClaimException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) Instantiates the classUnsatisfiedClaimException.UnsatisfiedClaimException(String aMessage, Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates the classUnsatisfiedClaimException.UnsatisfiedClaimException(Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) Instantiates the classUnsatisfiedClaimException.UnsatisfiedClaimException(Claim aClaim, Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates the classUnsatisfiedClaimException.