Uses of Interface
org.refcodes.decoupling.ClaimsAccessor
-
Uses of ClaimsAccessor in org.refcodes.decoupling
Subinterfaces of ClaimsAccessor in org.refcodes.decouplingClasses in org.refcodes.decoupling that implement ClaimsAccessorModifier and TypeClassDescriptionclassDependency<T>ADependencydescribes a component wired together by theReactorwith other components also defined byDependencyinstances.classADependencyBuilderdescribes a component or module depending on or required by other components or modules.protected static classTheDependencyException.DependencyClaimExceptionis aDependencyExceptioncontaining an additional relatedClaiminstance relative to associatedClaiminstances.classTheDuplicateClaimExceptionis thrown in case there are multiple identical claims declared by aDependency.