Uses of Class
org.refcodes.decoupling.Dependency
-
Uses of Dependency in org.refcodes.decoupling
Subclasses of Dependency in org.refcodes.decouplingModifier and TypeClassDescriptionclassADependencyBuilderdescribes a component or module depending on or required by other components or modules.Fields in org.refcodes.decoupling declared as DependencyMethods in org.refcodes.decoupling that return DependencyModifier and TypeMethodDescriptionDependency<?>[]Context.getDependencies()Retrieves theDependencydeclarations contained in theContext.Dependency<T>[]DependenciesAccessor.getDependencies()Retrieves the dependencies from the dependencies property.Dependency<?>[]DependencyException.DependenciesException.getDependencies()Retrieves theDependencydeclarations related to this exception.Dependency<?>[]Context.getDependenciesByProfiles(Object... aProfiles) Retrieves theDependencydeclarations of given profiles managed by thisContext, derived from theDependencyDependencydeclarations from which theReactorcreated thisContext.Dependency<?>[]Context.getDependenciesByTags(Object... aTags) Retrieves theDependencydeclarations of given tags managed by thisContext, derived from theDependencyDependencydeclarations from which theReactorcreated thisContext.<T> Dependency<T>[]Context.getDependenciesByType(Class<T> aType) Retrieves theDependencydeclarations of the given type managed by thisContext, derived from theDependencydeclarations from which theReactorcreated thisContext.DependencyAccessor.getDependency()Retrieves the dependency from the dependency property.Dependency<?>DependencyException.getDependency()Retrieves the dependency from the dependency property.Dependency<?>Context.getDependencyByAlias(String aAlias) Retrieves theDependencydeclaration with the given alias managed by thisContext, derived from theDependencyDependencydeclaration from which theReactorcreated thisContext.Dependency<?>Context.getDependencyByInstance(Object aInstance) Determines theDependencyelement for the given instance created from theDependency.default Dependency<T>[]DependenciesAccessor.DependenciesProperty.letDependencies(Dependency<T>[] aDependencies) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenDependency(setter) as ofDependenciesAccessor.DependenciesMutator.setDependencies(Dependency[])and returns the very same value (getter).default Dependency<T>DependencyAccessor.DependencyProperty.letDependency(Dependency<T> aDependency) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenDependency<T>(setter) as ofDependencyAccessor.DependencyMutator.setDependency(Dependency)and returns the very same value (getter).Methods in org.refcodes.decoupling with parameters of type DependencyModifier and TypeMethodDescriptionintDependency.compareTo(Dependency<T> aDependency) DependencyInterceptor.intercept(Object aInstance, Dependency<?> aDependency) Called by theReactorfor all registeredDependencyInterceptorinstances upon invoking theReactor.createContext()(or the like) methods (this is the moment when theReactorcreated theDependencydeclarations' types).protected <T> TReactor.intercept(T aInstance, Dependency<T> aDependency) Invokes all registeredDependencyInterceptorinstances for the givenDependencydeclaration's instance for intercepting purposes.booleanClaim.isClaim(Dependency<?> aDependency) Determines whether the givenDependencydeclaration matches thisClaiminstance.default Dependency<T>[]DependenciesAccessor.DependenciesProperty.letDependencies(Dependency<T>[] aDependencies) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenDependency(setter) as ofDependenciesAccessor.DependenciesMutator.setDependencies(Dependency[])and returns the very same value (getter).default Dependency<T>DependencyAccessor.DependencyProperty.letDependency(Dependency<T> aDependency) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenDependency<T>(setter) as ofDependencyAccessor.DependencyMutator.setDependency(Dependency)and returns the very same value (getter).voidDependenciesAccessor.DependenciesMutator.setDependencies(Dependency<T>[] aDependencies) Sets the dependencies for the dependencies property.voidDependencyAccessor.DependencyMutator.setDependency(Dependency<T> aDependency) Sets the dependency for the dependency property.protected TDependency.toInstance(Dependency<?>[] aDependencies, Object... aProfiles) Creates theDependency's instance as of its type using the providedDependencydeclarations.protected TDependency.toInstance(Dependency<?>[] aDependencies, Set<Dependency<?>> aVistedDependencies, Object... aProfiles) Creates theDependency's instance as of its type using the providedDependencydeclarations.DependenciesAccessor.DependenciesBuilder.withDependencies(Dependency<T>[] aDependencies) Sets the dependencies for the dependencies property.DependencyAccessor.DependencyBuilder.withDependency(Dependency<T> aDependency) Sets the dependency for the dependency property.Method parameters in org.refcodes.decoupling with type arguments of type DependencyModifier and TypeMethodDescriptionprotected TDependency.toInstance(Dependency<?>[] aDependencies, Set<Dependency<?>> aVistedDependencies, Object... aProfiles) Creates theDependency's instance as of its type using the providedDependencydeclarations.Constructors in org.refcodes.decoupling with parameters of type DependencyModifierConstructorDescriptionAliasDependenciesException(Dependency<?> aDependency, String aAlias, Dependency<?>[] aDependencies, String aMessage) Instantiates a newDependencyException.AliasDependenciesException.AliasDependenciesException(Dependency<?> aDependency, String aAlias, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) Instantiates a newDependencyException.AliasDependenciesException.AliasDependenciesException(Dependency<?> aDependency, String aAlias, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) Instantiates a newDependencyException.AliasDependenciesException.AliasDependenciesException(Dependency<?> aDependency, String aAlias, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.AliasDependenciesException.AliasDependenciesException(Dependency<?> aDependency, String aAlias, Dependency<?>[] aDependencies, Throwable aCause) Instantiates a newDependencyException.AliasDependenciesException.AliasDependenciesException(Dependency<?> aDependency, String aAlias, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.AliasDependenciesException.AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage) AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause) AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) AmbigousDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage) AmbigousDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) AmbigousDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) AmbigousDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) AmbigousDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) AmbigousDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) AmbigousFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, String aMessage) AmbigousFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) AmbigousFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) AmbigousFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) AmbigousFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, Throwable aCause) AmbigousFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) AmbigousInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, String aMessage) AmbigousInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) AmbigousInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) AmbigousInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) AmbigousInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, Throwable aCause) AmbigousInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) CircularDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage) CircularDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) CircularDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) CircularDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) CircularDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) CircularDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage) Instantiates a newDependencyException.ClaimDependenciesException.ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) Instantiates a newDependencyException.ClaimDependenciesException.ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) Instantiates a newDependencyException.ClaimDependenciesException.ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.ClaimDependenciesException.ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause) Instantiates a newDependencyException.ClaimDependenciesException.ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.ClaimDependenciesException.Context(Dependency<?>[] aDependencies, Object[] aProfiles) Creates theContextwith the managedDependencyinstances.DependenciesException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage) Instantiates a newDependencyException.DependenciesException.DependenciesException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) Instantiates a newDependencyException.DependenciesException.DependenciesException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) Instantiates a newDependencyException.DependenciesException.DependenciesException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.DependenciesException.DependenciesException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) Instantiates a newDependencyException.DependenciesException.DependenciesException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.DependenciesException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage) Instantiates a newDependencyException.DependencyClaimException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, String aErrorCode) Instantiates a newDependencyException.DependencyClaimException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, Throwable aCause) Instantiates a newDependencyException.DependencyClaimException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.DependencyClaimException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, Throwable aCause) Instantiates a newDependencyException.DependencyClaimException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.DependencyClaimException.DependencyException(Dependency<?> aDependency, String aMessage) Instantiates a newDependencyException.DependencyException(Dependency<?> aDependency, String aMessage, String aErrorCode) Instantiates a newDependencyException.DependencyException(Dependency<?> aDependency, String aMessage, Throwable aCause) Instantiates a newDependencyException.DependencyException(Dependency<?> aDependency, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.DependencyException(Dependency<?> aDependency, Throwable aCause) Instantiates a newDependencyException.DependencyException(Dependency<?> aDependency, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.DependencyInstanciationException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage) DependencyInstanciationException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) DependencyInstanciationException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) DependencyInstanciationException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) DependencyInstanciationException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) DependencyInstanciationException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) DependencySchema(Dependency<?> aDependency, org.refcodes.mixin.Schema... aChildren) Constructs aDependencySchemafrom the providedDependencyand the provided arguments.DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage) DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, String aErrorCode) DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, Throwable aCause) DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, Throwable aCause, String aErrorCode) DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, Throwable aCause) DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, Throwable aCause, String aErrorCode) DuplicateDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage) DuplicateDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) DuplicateDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) DuplicateDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) DuplicateDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) DuplicateDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) FactoryDependenciesException(Dependency<?> aDependency, FactoryClaim aFactoryClaim, Dependency<?>[] aDependencies, String aMessage) Instantiates a newDependencyException.FactoryDependenciesException.FactoryDependenciesException(Dependency<?> aDependency, FactoryClaim aFactoryClaim, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) Instantiates a newDependencyException.FactoryDependenciesException.FactoryDependenciesException(Dependency<?> aDependency, FactoryClaim aFactoryClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) Instantiates a newDependencyException.FactoryDependenciesException.FactoryDependenciesException(Dependency<?> aDependency, FactoryClaim aFactoryClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.FactoryDependenciesException.FactoryDependenciesException(Dependency<?> aDependency, FactoryClaim aFactoryClaim, Dependency<?>[] aDependencies, Throwable aCause) Instantiates a newDependencyException.FactoryDependenciesException.FactoryDependenciesException(Dependency<?> aDependency, FactoryClaim aFactoryClaim, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.FactoryDependenciesException.InitializerDependenciesException(Dependency<?> aDependency, InitializerClaim aInitializerClaim, Dependency<?>[] aDependencies, String aMessage) Instantiates a newDependencyException.InitializerDependenciesException.InitializerDependenciesException(Dependency<?> aDependency, InitializerClaim aInitializerClaim, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) Instantiates a newDependencyException.InitializerDependenciesException.InitializerDependenciesException(Dependency<?> aDependency, InitializerClaim aInitializerClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) Instantiates a newDependencyException.InitializerDependenciesException.InitializerDependenciesException(Dependency<?> aDependency, InitializerClaim aInitializerClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.InitializerDependenciesException.InitializerDependenciesException(Dependency<?> aDependency, InitializerClaim aInitializerClaim, Dependency<?>[] aDependencies, Throwable aCause) Instantiates a newDependencyException.InitializerDependenciesException.InitializerDependenciesException(Dependency<?> aDependency, InitializerClaim aInitializerClaim, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.InitializerDependenciesException.InstallDependencyException(Dependency<?> aDependency, String aMessage) InstallDependencyException(Dependency<?> aDependency, String aMessage, String aErrorCode) InstallDependencyException(Dependency<?> aDependency, String aMessage, Throwable aCause) InstallDependencyException(Dependency<?> aDependency, String aMessage, Throwable aCause, String aErrorCode) InstallDependencyException(Dependency<?> aDependency, Throwable aCause) InstallDependencyException(Dependency<?> aDependency, Throwable aCause, String aErrorCode) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) UnsatisfiedDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage) UnsatisfiedDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) UnsatisfiedDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) UnsatisfiedDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) UnsatisfiedDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause) UnsatisfiedDependencyException(Dependency<?> aDependency, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) UnsatisfiedFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, String aMessage) UnsatisfiedFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) UnsatisfiedFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) UnsatisfiedFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) UnsatisfiedFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, Throwable aCause) UnsatisfiedFactoryException(Dependency<?> aDependency, FactoryClaim<?, ?> aFactory, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) UnsatisfiedInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, String aMessage) UnsatisfiedInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) UnsatisfiedInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) UnsatisfiedInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) UnsatisfiedInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, Throwable aCause) UnsatisfiedInitializerException(Dependency<?> aDependency, InitializerClaim<?, ?> aSetup, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode)