Uses of Class
org.refcodes.decoupling.DependencyException
-
Uses of DependencyException in org.refcodes.decoupling
Subclasses of DependencyException in org.refcodes.decouplingModifier and TypeClassDescriptionclassTheAmbigousClaimExceptionis thrown in case oneClaiminstance can be matched by multiple dependencies.classTheAmbigousDependencyExceptionis thrown in case for a requiredDependencythere are more than one matchingDependencycandidates in theReactor.classTheAmbigousFactoryExceptionis thrown in case oneFactoryClaiminstance can be matched by multiple dependencies.classTheAmbigousInitializerExceptionis thrown in case oneInitializerClaiminstance can be matched by multiple dependencies.classTheCircularDependencyExceptionis thrown in case there is some (transitive) circular dependency between twoDependencydeclarations.protected static classTheDependencyException.ClaimDependenciesExceptionis aDependencyException.DependenciesExceptioncontaining an additional relatedClaiminstance.protected static classTheDependencyException.DependenciesExceptionis aDependencyExceptioncontaining additional related dependency.protected static classTheDependencyException.DependencyClaimExceptionis aDependencyExceptioncontaining an additional relatedClaiminstance relative to associatedClaiminstances.protected static classTheDependencyException.FactoryDependenciesExceptionis aDependencyException.DependenciesExceptioncontaining an additional relatedFactoryClaiminstance.protected static classTheDependencyException.InitializerDependenciesExceptionis aDependencyException.DependenciesExceptioncontaining an additional relatedInitializerClaiminstance.classTheDependencyInstanciationExceptionis thrown in case aDependency's instance cannot be instantiated.classTheDuplicateClaimExceptionis thrown in case there are multiple identical claims declared by aDependency.classTheDuplicateDependencyExceptionis thrown in case there are multiple identical dependencies applicable by theReactor.classThis exception is thrown when trying to install aDependencyinto theContext, though installing failed due to the dependency throwing an exception during the process of installing (e.g. instantiation).classTheUnsatisfiedClaimExceptionis thrown in case aClaiminstance cannot be satisfied by any knownDependencydeclaration.classTheUnsatisfiedDependencyExceptionis thrown in case for a requiredDependencynone matchingDependencycandidates in theReactorhave been found (taking the profiles applied into account) for the constructors of the givenDependency.classTheUnsatisfiedFactoryExceptionis thrown in case aFactoryClaiminstance cannot be satisfied by any knownDependencydeclaration.classTheUnsatisfiedInitializerExceptionis thrown in case aInitializerClaiminstance cannot be satisfied by any knownDependencydeclaration.