Uses of Class
org.refcodes.decoupling.DependencyInstanciationException
-
Uses of DependencyInstanciationException in org.refcodes.decoupling
Subclasses of DependencyInstanciationException in org.refcodes.decouplingModifier and TypeClassDescriptionclassTheAmbigousDependencyExceptionis thrown in case for a requiredDependencythere are more than one matchingDependencycandidates in theReactor.classTheCircularDependencyExceptionis thrown in case there is some (transitive) circular dependency between twoDependencydeclarations.classTheDuplicateDependencyExceptionis thrown in case there are multiple identical dependencies applicable by theReactor.classTheUnsatisfiedDependencyExceptionis thrown in case for a requiredDependencynone matchingDependencycandidates in theReactorhave been found (taking the profiles applied into account) for the constructors of the givenDependency.Methods in org.refcodes.decoupling that throw DependencyInstanciationExceptionModifier and TypeMethodDescriptionDependency.toInstance()Creates theDependency's instance using the preparedDependencydeclarations (theDependencydeclarations are prepared by theReactor'sReactor.createContext()and the like methods and in turn by the underlyingDependency.toInstance()methods).