Uses of Enum Class
org.refcodes.decoupling.InstanceMode
-
Uses of InstanceMode in org.refcodes.decoupling
Subclasses with type arguments of type InstanceMode in org.refcodes.decouplingModifier and TypeClassDescriptionenumTheInstanceModedescribes how an instance for aDependencyis managed (instantiated).Methods in org.refcodes.decoupling that return InstanceModeModifier and TypeMethodDescriptionstatic InstanceModeReturns the enum constant of this class with the specified name.static InstanceMode[]InstanceMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.decoupling with parameters of type InstanceModeModifier and TypeMethodDescriptionvoidDependencyBuilder.setInstanceMetrics(InstanceMode aInstanceMode) Sets theInstanceModewhich describes how an instance for aDependencyis managed.DependencyBuilder.withInstanceMetrics(InstanceMode aInstanceMode) Builder method for theDependencyBuilder.setInstanceMetrics(InstanceMode)method.