Package org.refcodes.decoupling


package org.refcodes.decoupling
This artifact provides a Reactor for breaking up dependencies between a Java software system's components or modules, which enables them to be developed and tested independently (dependency injection and inversion of control). The Reactor wires components or modules together to form an interacting application. The Reactor uses dependency injection and inversion of control, which are two techniques that help achieve decoupling by allowing components to depend on abstractions instead of concrete implementations. The Reactor is configured with Dependency definitions to create a Context representing the wired dependencies.

Please refer to the refcodes-decoupling: Breaking up dependencies between components documentation for an up-to-date and detailed description on the usage of this artifact.