All Classes and Interfaces
Class
Description
The
Alias annotation denotes a parameter with an additional alias for
tackling such a parameter with a Dependency's alias (as of
Dependency.getAlias() when resolving dependencies.The
AmbigousClaimException is thrown in case one Claim
instance can be matched by multiple dependencies.The
AmbigousDependencyException is thrown in case for a required
Dependency there are more than one matching Dependency
candidates in the Reactor.The
AmbigousFactoryException is thrown in case one
FactoryClaim instance can be matched by multiple dependencies.The
AmbigousInitializerException is thrown in case one
InitializerClaim instance can be matched by multiple dependencies.The
CircularDependencyException is thrown in case there is some
(transitive) circular dependency between two Dependency declarations.A claim describes a
Claim required by a Dependency.Provides an accessor for a
Claim instance property.Provides a builder method for a
Claim instance property returning
the builder for applying multiple build operations.Provides a mutator for a
Claim instance property.Provides a
Claim instance property.Provides an accessor for a
Claim instances property.Provides a builder method for a
Claim instances property
returning the builder for applying multiple build operations.Provides a mutator for a
Claim instances property.Provides a
Claim instances property.Provides an accessor for a dependencies property.
Provides a builder method for a dependencies property returning the
builder for applying multiple build operations.
Provides a mutator for a dependencies property.
Provides a dependencies property.
A
Dependency describes a component wired together by the
Reactor with other components also defined by Dependency
instances.Provides an accessor for a dependency property.
Provides a builder method for a dependency property returning the builder
for applying multiple build operations.
Provides a mutator for a dependency property.
Provides a dependency property.
A
DependencyBuilder describes a component or module depending on or
required by other components or modules.The
DependencyException is the base checked exception for the
refcodes-decoupling package.The
DependencyException.ClaimDependenciesException is a DependencyException.DependenciesException
containing an additional related Claim instance.The
DependencyException.DependenciesException is a DependencyException
containing additional related dependency.The
DependencyException.DependencyClaimException is a DependencyException
containing an additional related Claim instance relative to
associated Claim instances.The
DependencyException.FactoryDependenciesException is a
DependencyException.DependenciesException containing an additional related
FactoryClaim instance.The
DependencyException.InitializerDependenciesException is a
DependencyException.DependenciesException containing an additional related
InitializerClaim instance.The
DependencyInstanciationException is thrown in case a
Dependency's instance cannot be instantiated.The
DependencyInterceptor is a FunctionalInterface used to
hook into the process of creating instances from a Dependency
declaration: The instance being created can be decorated or enriched with
functionality providing means to implement a proxy mechanism or a decorator.The purpose of a
DependencySchema is to automatically outline and
generate documentation of Dependency configuration.DependencySchema.Builder to build DependencySchema.The
DuplicateClaimException is thrown in case there are multiple
identical claims declared by a Dependency.The
DuplicateDependencyException is thrown in case there are multiple
identical dependencies applicable by the Reactor.A
FactoryClaim extends a Claim and uses a Function
upon a Dependency to create (fabricate) an instance.A
InitializerClaim extends a Claim and uses a
BiFunction upon a Dependency to initialize a given instance.This exception is thrown when trying to install a
Dependency into the
Context, though installing failed due to the dependency throwing an
exception during the process of installing (e.g. instantiation).The
InstanceMetrics define the creation of a Dependency's
instance and it's combinations are provided for convenience means by the
enumeration InstanceMode.Provides an accessor for a
InstanceMetrics property.Provides a builder method for a
InstanceMetrics property
returning the builder for applying multiple build operations.Provides a mutator for a
InstanceMetrics property.Provides a
InstanceMetrics property.The
InstanceMode describes how an instance for a Dependency
is managed (instantiated).Provides an accessor for a profiles property.
Provides a builder method for a profiles property returning the builder
for applying multiple build operations.
Provides a mutator for a profiles property.
Provides a profiles property.
A
Reactor's instance is used for breaking up dependencies between a
Java software system's components or modules, which enables them to be
developed and tested independently (dependency injection and inversion of
control).Provides an accessor for a tags property.
Provides a builder method for a tags property returning the builder for
applying multiple build operations.
Provides a mutator for a tags property.
Provides a tags property.
The
UnsatisfiedClaimException is thrown in case a Claim
instance cannot be satisfied by any known Dependency declaration.The
UnsatisfiedDependencyException is thrown in case for a required
Dependency none matching Dependency candidates in the
Reactor have been found (taking the profiles applied into account)
for the constructors of the given Dependency.The
UnsatisfiedFactoryException is thrown in case a
FactoryClaim instance cannot be satisfied by any known
Dependency declaration.The
UnsatisfiedInitializerException is thrown in case a
InitializerClaim instance cannot be satisfied by any known
Dependency declaration.