java.lang.Object
java.util.AbstractMap<String,Object>
java.util.HashMap<String,Object>
org.refcodes.schema.Schema
org.refcodes.decoupling.DependencySchema
- All Implemented Interfaces:
Serializable,Cloneable,Map<String,,Object> org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.ChildrenAccessor<org.refcodes.schema.Schema[]>,org.refcodes.mixin.CommentAccessor,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.SizeAccessor,org.refcodes.mixin.TypeAccessor
public class DependencySchema
extends org.refcodes.schema.Schema
implements org.refcodes.mixin.CommentAccessor, org.refcodes.mixin.SizeAccessor
The purpose of a
DependencySchema is to automatically outline and
generate documentation of Dependency configuration.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class java.util.AbstractMap
AbstractMap.SimpleEntry<K,V>, AbstractMap.SimpleImmutableEntry<K, V> Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ChildrenAccessor
org.refcodes.mixin.ChildrenAccessor.ChildrenBuilder<T,B extends org.refcodes.mixin.ChildrenAccessor.ChildrenBuilder<T, B>>, org.refcodes.mixin.ChildrenAccessor.ChildrenMutator<T>, org.refcodes.mixin.ChildrenAccessor.ChildrenProperty<T> Nested classes/interfaces inherited from interface org.refcodes.mixin.CommentAccessor
org.refcodes.mixin.CommentAccessor.CommentBuilder<B extends org.refcodes.mixin.CommentAccessor.CommentBuilder<B>>, org.refcodes.mixin.CommentAccessor.CommentMutator, org.refcodes.mixin.CommentAccessor.CommentPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.SizeAccessor
org.refcodes.mixin.SizeAccessor.SizeBuilder<B extends org.refcodes.mixin.SizeAccessor.SizeBuilder<B>>, org.refcodes.mixin.SizeAccessor.SizeMutator, org.refcodes.mixin.SizeAccessor.SizePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final StringFields inherited from class org.refcodes.schema.Schema
ALIAS, COMMENT, DESCRIPTION, EXCEPTION, KEY, TYPE, VALUE, VERBOSE -
Constructor Summary
ConstructorsConstructorDescriptionDependencySchema(Class<?> aType, String aDescription, org.refcodes.schema.Schema... aChildren) DependencySchema(String aAlias, Class<?> aType, String aDescription) DependencySchema(String aAlias, Class<?> aType, String aDescription, org.refcodes.schema.Schema... aChildren) DependencySchema(Claim aClaim) Constructs aDependencySchemafrom the providedClaim.DependencySchema(Dependency<?> aDependency, org.refcodes.schema.Schema... aChildren) Constructs aDependencySchemafrom the providedDependencyand the provided arguments.DependencySchema(FactoryClaim<?, ?> aFactoryClaim) Constructs aDependencySchemafrom the providedFactoryClaim.DependencySchema(InitializerClaim<?, ?> aInitializerClaim) Constructs aDependencySchemafrom the providedInitializerClaim. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the verbose representation of the value.intgetSize()Methods inherited from class org.refcodes.schema.Schema
getAlias, getChildren, getDescription, getType, toString, visitMethods inherited from class java.util.HashMap
clear, clone, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, forEach, get, getOrDefault, isEmpty, keySet, merge, newHashMap, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, valuesMethods inherited from class java.util.AbstractMap
equals, hashCode
-
Field Details
-
DEPENDENCY
- See Also:
-
FACTORY
- See Also:
-
INSTANCES
- See Also:
-
MANDATORY
- See Also:
-
PROFILES
- See Also:
-
SETUP
- See Also:
-
SINGLETON
- See Also:
-
SIZE
- See Also:
-
TAGS
- See Also:
-
-
Constructor Details
-
DependencySchema
-
DependencySchema
-
DependencySchema
-
DependencySchema
Constructs aDependencySchemafrom the providedClaim.- Parameters:
aClaim- TheClaimfrom which to construct the schema.
-
DependencySchema
Constructs aDependencySchemafrom the providedFactoryClaim.- Parameters:
aFactoryClaim- TheFactoryClaimfrom which to construct the schema.
-
DependencySchema
Constructs aDependencySchemafrom the providedInitializerClaim.- Parameters:
aInitializerClaim- TheInitializerClaimfrom which to construct the schema.
-
DependencySchema
Constructs aDependencySchemafrom the providedDependencyand the provided arguments.- Parameters:
aDependency- TheDependencyfrom which to retrieve the meta data of the schema.aChildren- The children'sDependencySchemadescriptions representing part of theDependencySchemaproviding type.
-
-
Method Details
-
getComment
Retrieves the verbose representation of the value.- Specified by:
getCommentin interfaceorg.refcodes.mixin.CommentAccessor- Returns:
- The human readable value representation.
-
getSize
public int getSize()- Specified by:
getSizein interfaceorg.refcodes.mixin.SizeAccessor
-