Class FactoryClaim<C,T>

java.lang.Object
org.refcodes.decoupling.Claim
org.refcodes.decoupling.FactoryClaim<C,T>
Type Parameters:
C - The type of the Dependency claimed for fabricating instances of the given type.
T - The type of the instance to be created.
All Implemented Interfaces:
Comparable<Claim>, org.refcodes.factory.ContextTypeFactory<T,C>, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.TypeAccessor, org.refcodes.schema.Schemable

public class FactoryClaim<C,T> extends Claim implements org.refcodes.factory.ContextTypeFactory<T,C>
A FactoryClaim extends a Claim and uses a Function upon a Dependency to create (fabricate) an instance.