Class InstallDependencyException

java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.decoupling.DependencyException
org.refcodes.decoupling.InstallDependencyException
All Implemented Interfaces:
Serializable, DependencyAccessor, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap

public class InstallDependencyException extends DependencyException
This exception is thrown when trying to install a Dependency into the Context, though installing failed due to the dependency throwing an exception during the process of installing (e.g. instantiation).
See Also: