Class InstallDependencyException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.decoupling.DependencyException
org.refcodes.decoupling.InstallDependencyException
- All Implemented Interfaces:
Serializable, DependencyAccessor, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap
This exception is thrown when trying to install a
Dependency into the
Context, though installing failed due to the dependency throwing an
exception during the process of installing (e.g. instantiation).- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class DependencyException
DependencyException.ClaimDependenciesException, DependencyException.DependenciesException, DependencyException.DependencyClaimException, DependencyException.FactoryDependenciesException, DependencyException.InitializerDependenciesExceptionNested classes/interfaces inherited from interface DependencyAccessor
DependencyAccessor.DependencyBuilder<T,B>, DependencyAccessor.DependencyMutator<T>, DependencyAccessor.DependencyProperty<T> Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty -
Field Summary
Fields inherited from class DependencyException
_dependency -
Constructor Summary
ConstructorsConstructorDescriptionInstallDependencyException(String aMessage, Dependency<?> aDependency) InstallDependencyException(String aMessage, Dependency<?> aDependency, String aErrorCode) InstallDependencyException(String aMessage, Dependency<?> aDependency, Throwable aCause) InstallDependencyException(String aMessage, Dependency<?> aDependency, Throwable aCause, String aErrorCode) InstallDependencyException(Dependency<?> aDependency, Throwable aCause) InstallDependencyException(Dependency<?> aDependency, Throwable aCause, String aErrorCode) -
Method Summary
Methods inherited from class DependencyException
getDependency, getPatternArgumentsMethods inherited from class org.refcodes.exception.AbstractException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
InstallDependencyException
-
InstallDependencyException
public InstallDependencyException(String aMessage, Dependency<?> aDependency, Throwable aCause, String aErrorCode) -
InstallDependencyException
-
InstallDependencyException
-
InstallDependencyException
-
InstallDependencyException
-