Interface InstanceMetrics
- All Known Implementing Classes:
InstanceMode
public interface InstanceMetrics
The
InstanceMetrics define the creation of a Dependency's
instance and it's combinations are provided for convenience means by the
enumeration InstanceMode.-
Method Summary
Modifier and TypeMethodDescriptionbooleanTrue in case aDependencyis required to be instantiated in any case, even if not being demanded by another dependency.booleanTrue in case theDependencyrepresents a singleton.
-
Method Details
-
isSingleton
boolean isSingleton()True in case theDependencyrepresents a singleton.- Returns:
- True in case of being a singleton
Dependency.
-
isMandatory
boolean isMandatory()True in case aDependencyis required to be instantiated in any case, even if not being demanded by another dependency.- Returns:
- True in case of being a required
Dependency.
-