Module org.refcodes.decoupling
Package org.refcodes.decoupling
Interface ProfilesAccessor.ProfilesBuilder<B extends ProfilesAccessor.ProfilesBuilder<B>>
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- All Known Implementing Classes:
DependencyBuilder
- Enclosing interface:
- ProfilesAccessor
public static interface ProfilesAccessor.ProfilesBuilder<B extends ProfilesAccessor.ProfilesBuilder<B>>
Provides a builder method for a profiles property returning the builder
for applying multiple build operations.
-
Method Summary
Modifier and TypeMethodDescriptionwithProfiles(Object... aProfiles) Sets the profiles for the profiles property.
-
Method Details
-
withProfiles
Sets the profiles for the profiles property.- Parameters:
aProfiles- The profiles to be stored by the profiles property.- Returns:
- The builder for applying multiple build operations.
-