Uses of Class
org.refcodes.decoupling.Claim
-
Uses of Claim in org.refcodes.decoupling
Subclasses of Claim in org.refcodes.decouplingModifier and TypeClassDescriptionclassFactoryClaim<C,T> AFactoryClaimextends aClaimand uses aFunctionupon aDependencyto create (fabricate) an instance.classInitializerClaim<C,T> AInitializerClaimextends aClaimand uses aBiFunctionupon aDependencyto initialize a given instance.Fields in org.refcodes.decoupling with type parameters of type ClaimMethods in org.refcodes.decoupling that return ClaimModifier and TypeMethodDescriptionClaimAccessor.getClaim()DependencyException.ClaimDependenciesException.getClaim()Retrieves theClaiminstance responsible for this exception.DependencyException.DependencyClaimException.getClaim()Retrieves theClaiminstance responsible for this exception.Claim[]ClaimsAccessor.getClaims()Claim[]Dependency.getClaims()Claim[]DependencyException.DependencyClaimException.getClaims()Retrieves theClaiminstances related to this exception.default ClaimThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenClaim(setter) as ofClaimAccessor.ClaimMutator.setClaim(Claim)and returns the very same value (getter).default Claim[]This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenClaim(setter) as ofClaimsAccessor.ClaimsMutator.setClaims(Claim[])and returns the very same value (getter).Methods in org.refcodes.decoupling with parameters of type ClaimModifier and TypeMethodDescriptionbooleanintdefault ClaimThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenClaim(setter) as ofClaimAccessor.ClaimMutator.setClaim(Claim)and returns the very same value (getter).default Claim[]This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenClaim(setter) as ofClaimsAccessor.ClaimsMutator.setClaims(Claim[])and returns the very same value (getter).voidvoidvoidDependencyBuilder.withAddClaim(Claim aClaim) Builder method for the accordingDependencyBuilder.addClaim(Claim)method.ClaimsAccessor.ClaimsBuilder.withClaims(Claim... aClaims) DependencyBuilder.withClaims(Claim... aClaims) Method parameters in org.refcodes.decoupling with type arguments of type ClaimModifier and TypeMethodDescriptionvoidDependencyBuilder.setClaims(Collection<Claim> aClaims) Sets theClaiminstances to theDependencyBuilderinstance.DependencyBuilder.withClaims(Collection<Claim> aClaims) Builder method for theDependencyBuilder.setClaims(Claim[])method.Constructors in org.refcodes.decoupling with parameters of type ClaimModifierConstructorDescriptionAmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage) AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause) AmbigousClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage) Instantiates a newDependencyException.ClaimDependenciesException.ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) Instantiates a newDependencyException.ClaimDependenciesException.ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) Instantiates a newDependencyException.ClaimDependenciesException.ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.ClaimDependenciesException.ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause) Instantiates a newDependencyException.ClaimDependenciesException.ClaimDependenciesException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.ClaimDependenciesException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage) Instantiates a newDependencyException.DependencyClaimException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, String aErrorCode) Instantiates a newDependencyException.DependencyClaimException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, Throwable aCause) Instantiates a newDependencyException.DependencyClaimException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.DependencyClaimException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, Throwable aCause) Instantiates a newDependencyException.DependencyClaimException.DependencyClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, Throwable aCause, String aErrorCode) Instantiates a newDependencyException.DependencyClaimException.DependencySchema(Claim aClaim) Constructs aDependencySchemafrom the providedClaim.DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage) DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, String aErrorCode) DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, Throwable aCause) DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, String aMessage, Throwable aCause, String aErrorCode) DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, Throwable aCause) DuplicateClaimException(Dependency<?> aDependency, Claim aClaim, Claim[] aClaims, Throwable aCause, String aErrorCode) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, String aErrorCode) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, String aMessage, Throwable aCause, String aErrorCode) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause) UnsatisfiedClaimException(Dependency<?> aDependency, Claim aClaim, Dependency<?>[] aDependencies, Throwable aCause, String aErrorCode)